@@ -1,6 +1,8 @@
-from httpx import AsyncClient
+from httpx import AsyncClient, ConnectTimeout
 from fake_useragent import UserAgent
 import random
+from PIL import Image
+from io import BytesIO
 from re import findall
 import sqlite3
 import os
@@ -68,8 +70,76 @@ async def search_tags(tag, proxies):
     return True, tags
 
 
+def set_size(image):
+    # 人类的本质就是复读机，这段代码写得真辣鸡，应该可以用个什么算法吧，但是我懒
+    img = Image.open(BytesIO(image))
+    width, height = img.size
+
+    if width == 512 or width < 512:
+        width = 512
+    elif width == 640:
+        pass
+    elif width == 768:
+        pass
+    elif width == 1024 or width > 1024:
+        width = 1024
+    elif 512 < width < 640:
+        width1 = width - 512
+        width2 = abs(width - 640)
+        if width1 > width2:
+            width = 640
+        else:
+            width = 512
+    elif 640 < width < 768:
+        width1 = width - 640
+        width2 = abs(width - 768)
+        if width1 > width2:
+            width = 768
+        else:
+            width = 640
+    elif 768 < width < 1024:
+        width1 = width - 768
+        width2 = abs(width - 1024)
+        if width1 > width2:
+            width = 1024
+        else:
+            width = 768
+
+    if height == 512 or height < 512:
+        height = 512
+    elif height == 640:
+        pass
+    elif height == 768:
+        pass
+    elif height == 1024 or height > 1024:
+        height = 1024
+    elif 512 < height < 640:
+        height1 = height - 512
+        height2 = abs(height - 640)
+        if height1 > height2:
+            height = 640
+        else:
+            height = 512
+    elif 640 < height < 768:
+        height1 = height - 640
+        height2 = abs(height - 768)
+        if height1 > height2:
+            height = 768
+        else:
+            height = 640
+    elif 768 < height < 1024:
+        height1 = height - 768
+        height2 = abs(height - 1024)
+        if height1 > height2:
+            height = 1024
+        else:
+            height = 768
+
+    return width, height
+
+
 async def get_data(
-        post_url, prompt, proxies,
+        post_url, prompt, proxies, timeout,
         img=None, mode=None, strength=None,
         noise=None, size=None, uc=None,
         scale=None, steps=None, seed=None
@@ -100,11 +170,11 @@ async def get_data(
             }
         )
 
-    async with AsyncClient(headers=headers, proxies=proxies, timeout=None) as client:
+    async with AsyncClient(headers=headers, proxies=proxies, timeout=timeout) as client:
         try:
             resp = await client.post(url=post_url, json=data)
-        except Exception as error:
-            return False, error
+        except ConnectTimeout:
+            return False, "时间超过限制！"
         info = resp.text
 
         # 获取错误
